diff --git a/core/modules/comment/lib/Drupal/comment/CommentForm.php b/core/modules/comment/lib/Drupal/comment/CommentForm.php
index ad0de74..fe975cc 100644
--- a/core/modules/comment/lib/Drupal/comment/CommentForm.php
+++ b/core/modules/comment/lib/Drupal/comment/CommentForm.php
@@ -99,8 +99,8 @@ public function form(array $form, array &$form_state) {
     $is_admin = $comment->id() && $this->currentUser->hasPermission('administer comments');
 
     if (!$this->currentUser->isAuthenticated() && $anonymous_contact != COMMENT_ANONYMOUS_MAYNOT_CONTACT) {
-      $form['#attached']['library'][] = 'core/jquery.cookie';
-      $form['#attributes']['class'][] = 'user-info-from-cookie';
+      $form['#attached']['library'][] = 'core/drupal.form';
+      $form['#attributes']['data-user-info-from-browser'] = TRUE;
     }
 
     // If not replying to a comment, use our dedicated page callback for new
@@ -167,6 +167,9 @@ public function form(array $form, array &$form_state) {
       $form['author']['name']['#theme'] = 'username';
       $form['author']['name']['#account'] = $this->currentUser;
     }
+    elseif($this->currentUser->isAnonymous()) {
+      $form['author']['name']['#attributes']['data-drupal-default-value'] = \Drupal::config('user.settings')->get('anonymous');
+    }
 
     // Add author e-mail and homepage fields depending on the current user.
     $form['author']['mail'] = array(
@@ -382,11 +385,6 @@ public function save(array $form, array &$form_state) {
     $uri = $entity->urlInfo();
 
     if ($this->currentUser->hasPermission('post comments') && ($this->currentUser->hasPermission('administer comments') || $entity->{$field_name}->status == CommentItemInterface::OPEN)) {
-      // Save the anonymous user information to a cookie for reuse.
-      if ($this->currentUser->isAnonymous()) {
-        user_cookie_save(array_intersect_key($form_state['values'], array_flip(array('name', 'mail', 'homepage'))));
-      }
-
       $comment->save();
       $form_state['values']['cid'] = $comment->id();
 
diff --git a/core/modules/contact/lib/Drupal/contact/MessageForm.php b/core/modules/contact/lib/Drupal/contact/MessageForm.php
index d28a8cb..0062c24 100644
--- a/core/modules/contact/lib/Drupal/contact/MessageForm.php
+++ b/core/modules/contact/lib/Drupal/contact/MessageForm.php
@@ -99,8 +99,8 @@ public function form(array $form, array &$form_state) {
       '#required' => TRUE,
     );
     if ($user->isAnonymous()) {
-      $form['#attached']['library'][] = 'core/jquery.cookie';
-      $form['#attributes']['class'][] = 'user-info-from-cookie';
+      $form['#attached']['library'][] = 'core/drupal.form';
+      $form['#attributes']['data-user-info-from-browser'] = TRUE;
     }
     // Do not allow authenticated users to alter the name or e-mail values to
     // prevent the impersonation of other users.
@@ -196,8 +196,6 @@ public function save(array $form, array &$form_state) {
       // over the submitted form values.
       $sender->name = $message->getSenderName();
       $sender->mail = $message->getSenderMail();
-      // Save the anonymous user information to a cookie for reuse.
-      user_cookie_save(array('name' => $message->getSenderName(), 'mail' => $message->getSenderMail()));
       // For the e-mail message, clarify that the sender name is not verified; it
       // could potentially clash with a username on this site.
       $sender->name = t('!name (not verified)', array('!name' => $message->getSenderName()));
diff --git a/core/modules/user/lib/Drupal/user/RegisterForm.php b/core/modules/user/lib/Drupal/user/RegisterForm.php
index 30f3018..4132063 100644
--- a/core/modules/user/lib/Drupal/user/RegisterForm.php
+++ b/core/modules/user/lib/Drupal/user/RegisterForm.php
@@ -44,8 +44,7 @@ public function form(array $form, array &$form_state) {
       return new RedirectResponse(url('user/' . \Drupal::currentUser()->id(), array('absolute' => TRUE)));
     }
 
-    $form['#attached']['library'][] = 'core/jquery.cookie';
-    $form['#attributes']['class'][] = 'user-info-from-cookie';
+    $form['#attributes']['data-user-info-from-browser'] = TRUE;
 
     // Start with the default user account fields.
     $form = parent::form($form, $form_state, $account);

diff --git a/core/misc/form.js b/core/misc/form.js
index f752f31..fd1a192 100644
--- a/core/misc/form.js
+++ b/core/misc/form.js
@@ -191,21 +191,29 @@
   };
 
   /**
    * Prepopulate form fields with information from the visitor cookie.
    */
-  Drupal.behaviors.fillUserInfoFromCookie = {
+  Drupal.behaviors.fillUserInfoFromBrowser = {
     attach: function (context, settings) {
       var userInfo = ['name', 'mail', 'homepage'];
-      $('form.user-info-from-cookie').once('user-info-from-cookie', function () {
-        var $formContext = $(this);
-        var i, il, $element, cookie;
-        for (i = 0, il = userInfo.length; i < il; i += 1) {
-          $element = $formContext.find('[name=' + userInfo[i] + ']');
-          cookie = $.cookie('Drupal.visitor.' + userInfo[i]);
-          if ($element.length && cookie) {
-            $element.val(cookie);
+      var $forms = $('[data-user-info-from-browser]').once('user-info-from-browser');
+      if ($forms.length) {
+        userInfo.map(function (info) {
+          var $element = $forms.find('[name=' + info + ']');
+          var browserData = localStorage.getItem('Drupal.visitor.' + info);
+          var emptyOrDefault = ($element.val() === '' || ($element.attr('data-drupal-default-value') === $element.val()));
+          if ($element.length && emptyOrDefault && browserData) {
+            $element.val(browserData);
           }
-        }
+        });
+      }
+      $forms.on('submit', function () {
+        userInfo.map(function (info) {
+          var $element = $forms.find('[name=' + info + ']');
+          if ($element.length) {
+            localStorage.setItem('Drupal.visitor.' + info, $element.val());
+          }
+        });
       });
     }
   };
@@ -191,21 +191,29 @@
 
   /**
-   * Prepopulate form fields with information from the visitor cookie.
+   * Prepopulate form fields with information from the visitor browser.
    */